@@ -147,24 +147,6 @@ def search(db, query):
     return files
 
 
-def get_versions(package):
-    """Return the latest version if currently installed `package` is out of date."""
-    current_version = pkg_resources.get_distribution(package).version
-    current_version = current_version.partition("a")[0]  # TODO FIXME strips alpha/beta
-    update_available = False
-    versions_rss = webagt.get(
-        f"https://pypi.org/rss/project/{package}/releases.xml"
-    ).xml
-    latest_version = [
-        child.getchildren()[0].text
-        for child in versions_rss.getchildren()[0].getchildren()
-        if child.tag == "item"
-    ][0]
-    if semver.compare(current_version, latest_version) == -1:
-        update_available = latest_version
-    return current_version, update_available
-
-
 @app.wrap
 def set_working_dir(handler, main_app):
     web.tx.host.working_dir = working_dir
